@@ -43,14 +43,6 @@ time_t Bayonne::start_time = 0;
 AtomicCounter Bayonne::libexec_count = 0;
 unsigned Bayonne::compile_count;
 volatile bool Bayonne::image_loaded = false;
-bool Bayonne::provision_defines = true;
-bool Bayonne::provision_daemon = false;
-bool Bayonne::provision_system = false;
-bool Bayonne::provision_check = false;
-bool Bayonne::provision_user = false;
-bool Bayonne::provision_test = false;
-const char *Bayonne::provision_server = "bayonne";
-const char *Bayonne::provision_libexec = "libexec";
 
 Audio::Encoding Bayonne::peer_encoding = Audio::unknownEncoding;
 Audio::timeout_t Bayonne::peer_framing = 0;
@@ -96,19 +88,18 @@ Bayonne::statetab Bayonne::states[] = {
 	{"final", &BayonneSession::stateFinal, ' '},
 	{NULL, NULL, ' '}};
 
-const char *Bayonne::getKeypath(const char *key)
+bool Bayonne::getUserdata(void)
 {
-	static char keypath[128];
-
-        if(strnicmp(key + 1, "bayonne/", 8))
-                return key;
-
-        keypath[0] = *key;
-        key += 9;
-        snprintf(keypath + 1, sizeof(keypath) - 1, "%s/%s",
-                provision_server, key);
-        return keypath;
-}    
+#ifdef	WIN32
+	return false;
+#else
+	if(!getuid())
+		return false;
+	if(!Process::getEnv("HOME"))
+		return false;
+	return true;
+#endif
+}
 
 void Bayonne::waitLoaded(void)
 {
@@ -127,30 +118,9 @@ bool Bayonne::loadPlugin(const char *path)
         DSO *dso;
 
 #ifdef	WIN32
-#ifdef	HAVE_TESTING
-        if(!prefix && provision_test)
-#ifdef  _DEBUG
-                prefix = "DEBUG";
-#else
-                prefix = "RELEASE";
-#endif 
-#endif
 	if(!prefix)
 		prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Plugins";
 #else
-
-#ifdef	HAVE_TESTING
-	char prefixbuf[256];
-        if(!prefix && provision_test && !strchr(path, '/'))
-        {
-                snprintf(prefixbuf, sizeof(prefixbuf),
-                        "%s/modules/%s/.libs", SOURCE_FILES, path);
-                if(!isDir(prefixbuf))  
-                        snprintf(prefixbuf, sizeof(prefixbuf),
-                                "%s/modules/%s", SOURCE_FILES, path);
-                prefix = prefixbuf;
-        } 
-#endif
 	if(!prefix)
 		prefix = LIBDIR_FILES;
 #endif
@@ -197,31 +167,9 @@ bool Bayonne::loadMonitor(const char *path)
         DSO *dso;
 
 #ifdef	WIN32
-#ifdef	HAVE_TESTING
-        if(!prefix && provision_test)
-#ifdef  _DEBUG
-                prefix = "DEBUG";
-#else
-                prefix = "RELEASE";
-#endif 
-#endif
 	if(!prefix)
 		prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Monitors";
 #else
-
-#ifdef	HAVE_TESTING
-	char prefixbuf[256];
-
-        if(!prefix && provision_test && !strchr(path, '/'))
-        {
-                snprintf(prefixbuf, sizeof(prefixbuf),
-                        "%s/modules/%smon/.libs", SOURCE_FILES, path);
-                if(!isDir(prefixbuf))  
-                        snprintf(prefixbuf, sizeof(prefixbuf),
-                                "%s/modules/%smon", SOURCE_FILES, path);
-                prefix = prefixbuf;
-        } 
-#endif
 	if(!prefix)
 		prefix = LIBDIR_FILES;
 #endif
@@ -585,15 +533,9 @@ ScriptCompiler *Bayonne::reload(void)
 	compile_count = 0;
 
 	lock.enter();
-#ifdef	WIN32
-	img = new ScriptCompiler(server, "/bayonne/config");
-#else
-	img = new ScriptCompiler(server, getKeypath("/bayonne/server/config"));
-	if(provision_system)
-		img->loadPrefix("config", "/bayonne/provision/config");
-	else if(provision_user)
+	img = new ScriptCompiler(server, "/bayonne/server/config");
+	if(getUserdata())
 		img->loadPrefix("config", "~bayonne/config");
-#endif
 
 	img->setValue("text.cr", "\r");
 	img->setValue("text.nl", "\n");
