@@ -34,30 +34,12 @@ static Keydata::Define driver[] = {
 	{"buffersize", "128"},
         {NULL, NULL}};
 
-#ifdef	WIN32
-#define	KEYS	"/bayonne/capi"
-#else
-#define	KEYS	"/bayonne/driver/capi"
-#endif
-
 Driver Driver::capi;
 
 Driver::Driver() :
-BayonneDriver(driver, KEYS, "capi20", false),
+BayonneDriver(driver, "/bayonne/driver/capi", "capi20", false),
 Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 {
-#ifdef	WIN32
-	const char *env = Process::getEnv("DRIVERCONFIG");
-
-	if(env)
-		loadFile(env, "capi");
-#else
-	if(Bayonne::provision_system)
-		load("/bayonne/provision/capi");
-	else if(Bayonne::provision_user)
-		load("~bayonne/capi");
-#endif
-
 	server->setValue("trunk.conf", CONFIG_FILES "/trunk.conf");
         server->setValue("caller.conf", CONFIG_FILES "/caller.conf");
         server->setValue("dialed.conf", CONFIG_FILES "/dialed.conf");
