@@ -21,6 +21,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <sys/wait.h>
+#include <sys/stat.h>
 #include <signal.h>
 #include <fcntl.h>
 #include "private.h"
@@ -267,8 +268,6 @@ launch:
 
 int main(int argc, char **argv)
 {
-	struct sigaction timer_act, timer_old;
-	struct sigaction child_act, child_old;
 	char *buf, *p;
 	int len;
 	unsigned ts;
